local L = LibStub("AceLocale-3.0"):GetLocale("SliceCommander")

--Copyright ElvUI staticpopup.lua
--Cache global variables
--Lua functions
local _G = _G
local pairs, type, unpack, assert = pairs, type, unpack, assert
local tremove, tContains, tinsert, wipe = tremove, tContains, tinsert, table.wipe
local lower = string.lower
--WoW API / Variables
local CreateFrame = CreateFrame
local UnitIsDeadOrGhost, InCinematic = UnitIsDeadOrGhost, InCinematic
local GetBindingFromClick, RunBinding = GetBindingFromClick, RunBinding
local PurchaseSlot, GetBankSlotCost = PurchaseSlot, GetBankSlotCost
local MoneyFrame_Update = MoneyFrame_Update
local SetCVar, EnableAddOn, DisableAddOn = SetCVar, EnableAddOn, DisableAddOn
local ReloadUI, PlaySound, StopMusic = ReloadUI, PlaySound, StopMusic
local StaticPopup_Resize = StaticPopup_Resize
local AutoCompleteEditBox_OnEnterPressed = AutoCompleteEditBox_OnEnterPressed
local AutoCompleteEditBox_OnTextChanged = AutoCompleteEditBox_OnTextChanged
local ChatEdit_FocusActiveWindow = ChatEdit_FocusActiveWindow
local STATICPOPUP_TEXTURE_ALERT = STATICPOPUP_TEXTURE_ALERT
local STATICPOPUP_TEXTURE_ALERTGEAR = STATICPOPUP_TEXTURE_ALERTGEAR

function SliceCommander:LoadPopup()
	SC.PopupDialogs = {};
	SC.StaticPopup_DisplayedFrames = {};
	
	SC.PopupDialogs['FAILED_UISCALE'] = {
		text = L["You have changed your UIScale, however you still have the PixelPerfect option enabled in SliceCommander. Press accept if you would like to disable the Auto Scale option."],
		button1 = ACCEPT,
		button2 = CANCEL,
		OnAccept = function() SC.SET.PixelPerfect = false; ReloadUI(); end,
		timeout = 0,
		whileDead = 1,
		hideOnEscape = false,
	}

	SC.PopupDialogs["CONFIG_UNLOCK"] = {
		text = L["SliceCommander frames are currently unlocked. Accept to relock them."],
		button1 = ACCEPT,
		OnAccept = function() SliceCommander:LockCkecked(true) end,
		timeout = 0,
		whileDead = 1,
		hideOnEscape = false,
	}

	SC.PopupDialogs["CONFIG_RL"] = {
		text = L["One or more of the changes you have made require a ReloadUI."],
		button1 = ACCEPT,
		button2 = CANCEL,
		OnAccept = function() ReloadUI() end,
		timeout = 0,
		whileDead = 1,
		hideOnEscape = false,
	}

	SC.PopupDialogs["FAILED_UISCALERESOLUTION"] = {
		text = L["The resolution for the PixelPerfect option can not be found properly. You should try to change your client to fullscreen and then back to windowed. If does not fix the issue you can force the resolution for SliceCommander with the following macro '/sc resolution 1920x1080' (replace 1920x1080 by your resolution)."],
		button1 = ACCEPT,
		OnAccept = function() GameMenuButtonOptions:Click(); end,
		timeout = 0,
		whileDead = 1,
		hideOnEscape = false,
	}
end

local MAX_STATIC_POPUPS = 4

function SliceCommander:StaticPopup_OnShow()
	PlaySound("igMainMenuOpen");

	local dialog = SC.PopupDialogs[self.which];
	local OnShow = dialog.OnShow;

	if ( OnShow ) then
		OnShow(self, self.data);
	end
	if ( dialog.hasMoneyInputFrame ) then
		_G[self:GetName().."MoneyInputFrameGold"]:SetFocus();
	end
	if ( dialog.enterClicksFirstButton ) then
		self:SetScript("OnKeyDown", SC.StaticPopup_OnKeyDown);
	end
end

function SliceCommander:StaticPopup_EscapePressed()
	local closed = nil;
	for _, frame in pairs(SC.StaticPopup_DisplayedFrames) do
		if( frame:IsShown() and frame.hideOnEscape ) then
			local standardDialog = SC.PopupDialogs[frame.which];
			if ( standardDialog ) then
				local OnCancel = standardDialog.OnCancel;
				local noCancelOnEscape = standardDialog.noCancelOnEscape;
				if ( OnCancel and not noCancelOnEscape) then
					OnCancel(frame, frame.data, "clicked");
				end
				frame:Hide();
			else
				SliceCommander:StaticPopupSpecial_Hide(frame);
			end
			closed = 1;
		end
	end
	return closed;
end

function SliceCommander:StaticPopupSpecial_Hide(frame)
	frame:Hide();
	SliceCommander:StaticPopup_CollapseTable();
end

function SliceCommander:StaticPopup_CollapseTable()
	if (SC.StaticPopup_DisplayedFrames == nil) then
		SliceCommander:LoadPopup();
	end
	local displayedFrames = SC.StaticPopup_DisplayedFrames;
	local index = #displayedFrames;
	while ( ( index >= 1 ) and ( not displayedFrames[index]:IsShown() ) ) do
		tremove(displayedFrames, index);
		index = index - 1;
	end
end

function SliceCommander:StaticPopup_SetUpPosition(dialog)
	if not tContains(SC.StaticPopup_DisplayedFrames, dialog) then
		local lastFrame = SC.StaticPopup_DisplayedFrames[#SC.StaticPopup_DisplayedFrames];
		if lastFrame then
			dialog:SCPoint("TOP", lastFrame, "BOTTOM", 0, -4);
		else
			dialog:SCPoint("TOP", UIParent, "TOP", 0, -100);
		end
		tinsert(SC.StaticPopup_DisplayedFrames, dialog);
	end
end

function SliceCommander:StaticPopupSpecial_Show(frame)
	if ( frame.exclusive ) then
		SliceCommander:StaticPopup_HideExclusive();
	end
	SliceCommander:StaticPopup_SetUpPosition(frame);
	frame:Show();
end

function SliceCommander:StaticPopupSpecial_Hide(frame)
	frame:Hide();
	SliceCommander:StaticPopup_CollapseTable();
end

--Used to figure out if we can resize a frame
function SliceCommander:StaticPopup_IsLastDisplayedFrame(frame)
	for i=#SC.StaticPopup_DisplayedFrames, 1, -1 do
		local popup = SC.StaticPopup_DisplayedFrames[i];
		if ( popup:IsShown() ) then
			return frame == popup
		end
	end
	return false;
end

function SliceCommander:StaticPopup_OnKeyDown(key)
	if ( GetBindingFromClick(key) == "TOGGLEGAMEMENU" ) then
		return SliceCommander:StaticPopup_EscapePressed();
	elseif ( GetBindingFromClick(key) == "SCREENSHOT" ) then
		RunBinding("SCREENSHOT");
		return;
	end

	local dialog = SC.PopupDialogs[self.which];
	if ( dialog ) then
		if ( key == "ENTER" and dialog.enterClicksFirstButton ) then
			local frameName = self:GetName();
			local button;
			local i = 1;
			while ( true ) do
				button = _G[frameName.."Button"..i];
				if ( button ) then
					if ( button:IsShown() ) then
						SliceCommander:StaticPopup_OnClick(self, i);
						return;
					end
					i = i + 1;
				else
					break;
				end
			end
		end
	end
end

function SliceCommander:StaticPopup_OnHide()
	PlaySound("igMainMenuClose");

	SliceCommander:StaticPopup_CollapseTable();

	local dialog = SC.PopupDialogs[self.which];
	local OnHide = dialog.OnHide;
	if ( OnHide ) then
		OnHide(self, self.data);
	end
	self.extraFrame:Hide();
	if ( dialog.enterClicksFirstButton ) then
		self:SetScript("OnKeyDown", nil);
	end
end

function SliceCommander:StaticPopup_OnUpdate(elapsed)
	if ( self.timeleft and self.timeleft > 0 ) then
		local which = self.which;
		local timeleft = self.timeleft - elapsed;
		if ( timeleft <= 0 ) then
			if ( not SC.PopupDialogs[which].timeoutInformationalOnly ) then
				self.timeleft = 0;
				local OnCancel = SC.PopupDialogs[which].OnCancel;
				if ( OnCancel ) then
					OnCancel(self, self.data, "timeout");
				end
				self:Hide();
			end
			return;
		end
		self.timeleft = timeleft;
	end

	if ( self.startDelay ) then
		local which = self.which;
		local timeleft = self.startDelay - elapsed;
		if ( timeleft <= 0 ) then
			self.startDelay = nil;
			local text = _G[self:GetName().."Text"];
			text:SetFormattedText(SC.PopupDialogs[which].text, text.text_arg1, text.text_arg2);
			local button1 = _G[self:GetName().."Button1"];
			button1:Enable();
			StaticPopup_Resize(self, which);
			return;
		end
		self.startDelay = timeleft;
	end

	local onUpdate = SC.PopupDialogs[self.which].OnUpdate;
	if ( onUpdate ) then
		onUpdate(self, elapsed);
	end
end

function SliceCommander:StaticPopup_OnClick(index)
	if ( not self:IsShown() ) then
		return;
	end
	local which = self.which;
	local info = SC.PopupDialogs[which];
	if ( not info ) then
		return nil;
	end
	local hide = true;
	if ( index == 1 ) then
		local OnAccept = info.OnAccept;
		if ( OnAccept ) then
			hide = not OnAccept(self, self.data, self.data2);
		end
	elseif ( index == 3 ) then
		local OnAlt = info.OnAlt;
		if ( OnAlt ) then
			OnAlt(self, self.data, "clicked");
		end
	else
		local OnCancel = info.OnCancel;
		if ( OnCancel ) then
			hide = not OnCancel(self, self.data, "clicked");
		end
	end

	if ( hide and (which == self.which) ) then
		-- can self.which change inside one of the On* functions???
		self:Hide();
	end
end

function SliceCommander:StaticPopup_EditBoxOnEnterPressed()
	local EditBoxOnEnterPressed, which, dialog;
	local parent = self:GetParent();
	if ( parent.which ) then
		which = parent.which;
		dialog = parent;
	elseif ( parent:GetParent().which ) then
		-- This is needed if this is a money input frame since it's nested deeper than a normal edit box
		which = parent:GetParent().which;
		dialog = parent:GetParent();
	end
	if ( not self.autoCompleteParams or not AutoCompleteEditBox_OnEnterPressed(self) ) then
		EditBoxOnEnterPressed = SC.PopupDialogs[which].EditBoxOnEnterPressed;
		if ( EditBoxOnEnterPressed ) then
			EditBoxOnEnterPressed(self, dialog.data);
		end
	end
end

function SliceCommander:StaticPopup_EditBoxOnEscapePressed()
	local EditBoxOnEscapePressed = SC.PopupDialogs[self:GetParent().which].EditBoxOnEscapePressed;
	if ( EditBoxOnEscapePressed ) then
		EditBoxOnEscapePressed(self, self:GetParent().data);
	end
end

function SliceCommander:StaticPopup_EditBoxOnTextChanged(userInput)
	if ( not self.autoCompleteParams or not AutoCompleteEditBox_OnTextChanged(self, userInput) ) then
		local EditBoxOnTextChanged = SC.PopupDialogs[self:GetParent().which].EditBoxOnTextChanged;
		if ( EditBoxOnTextChanged ) then
			EditBoxOnTextChanged(self, self:GetParent().data);
		end
	end
end

function SliceCommander:StaticPopup_FindVisible(which, data)
	local info = SC.PopupDialogs[which];
	if ( not info ) then
		return nil;
	end
	for index = 1, MAX_STATIC_POPUPS, 1 do
		local frame = _G["SliceCommander_StaticPopup"..index];
		if ( frame:IsShown() and (frame.which == which) and (not info.multiple or (frame.data == data)) ) then
			return frame;
		end
	end
	return nil;
end

function SliceCommander:StaticPopup_Resize(dialog, which)
	local info = SC.PopupDialogs[which];
	if ( not info ) then
		return nil;
	end

	local text = _G[dialog:GetName().."Text"];
	local editBox = _G[dialog:GetName().."EditBox"];
	local button1 = _G[dialog:GetName().."Button1"];

	local maxHeightSoFar, maxWidthSoFar = (dialog.maxHeightSoFar or 0), (dialog.maxWidthSoFar or 0);
	local width = 500;
	
	text:SCWidth(470);
	text:SCHeight(90);

	if ( dialog.numButtons == 3 ) then
		width = 440;
	elseif (info.showAlert or info.showAlertGear or info.closeButton) then
		-- Widen
		width = 420;
	elseif ( info.editBoxWidth and info.editBoxWidth > 260 ) then
		width = width + (info.editBoxWidth - 260);
	end

	if ( width > maxWidthSoFar )  then
		dialog:SCWidth(width);
		dialog.maxWidthSoFar = width;
	end

	local height = 55 + text:GetHeight() + 8 + button1:GetHeight();
	if ( info.hasEditBox ) then
		height = height + 8 + editBox:GetHeight();
	elseif ( info.hasMoneyFrame ) then
		height = height + 16;
	elseif ( info.hasMoneyInputFrame ) then
		height = height + 22;
	end
	if ( info.hasItemFrame ) then
		height = height + 64;
	end

	if ( height > maxHeightSoFar ) then
		dialog:SCHeight(height);
		dialog.maxHeightSoFar = height;
	end
end

function SliceCommander:StaticPopup_OnEvent()
	self.maxHeightSoFar = 0;
	SliceCommander:StaticPopup_Resize(self, self.which);
end

local tempButtonLocs = {};	--So we don't make a new table each time.
function SliceCommander:StaticPopup_Show(which, text_arg1, text_arg2, data)
	if SC.PopupDialogs == nil then
		SliceCommander:LoadPopup()
	end
	local info = SC.PopupDialogs[which];
	if not info then
		return nil;
	end

	if UnitIsDeadOrGhost("player") and not info.whileDead then
		if info.OnCancel then
			info.OnCancel();
		end
		return nil;
	end

	if ( InCinematic() and not info.interruptCinematic ) then
		if ( info.OnCancel ) then
			info.OnCancel();
		end
		return nil;
	end

	if ( info.cancels ) then
		for index = 1, MAX_STATIC_POPUPS, 1 do
			local frame = _G["SliceCommander_StaticPopup"..index];
			if ( frame:IsShown() and (frame.which == info.cancels) ) then
				frame:Hide();
				local OnCancel = SC.PopupDialogs[frame.which].OnCancel;
				if ( OnCancel ) then
					OnCancel(frame, frame.data, "override");
				end
			end
		end
	end

	-- Pick a free dialog to use
	local dialog = nil;
	-- Find an open dialog of the requested type
	dialog = SliceCommander:StaticPopup_FindVisible(which, data);
	if ( dialog ) then
		if ( not info.noCancelOnReuse ) then
			local OnCancel = info.OnCancel;
			if ( OnCancel ) then
				OnCancel(dialog, dialog.data, "override");
			end
		end
		dialog:Hide();
	end
	if ( not dialog ) then
		-- Find a free dialog
		local index = 1;
		if ( info.preferredIndex ) then
			index = info.preferredIndex;
		end
		for i = index, MAX_STATIC_POPUPS do
			local frame = _G["SliceCommander_StaticPopup"..i];
			if ( not frame:IsShown() ) then
				dialog = frame;
				break;
			end
		end

		--If dialog not found and there's a preferredIndex then try to find an available frame before the preferredIndex
		if ( not dialog and info.preferredIndex ) then
			for i = 1, info.preferredIndex do
				local frame = _G["SliceCommander_StaticPopup"..i];
				if ( not frame:IsShown() ) then
					dialog = frame;
					break;
				end
			end
		end
	end
	if ( not dialog ) then
		if ( info.OnCancel ) then
			info.OnCancel();
		end
		return nil;
	end

	dialog.maxHeightSoFar, dialog.maxWidthSoFar = 0, 0;
	-- Set the text of the dialog
	local text = _G[dialog:GetName().."Text"];
	text:SetFormattedText(info.text, text_arg1, text_arg2);

	-- Show or hide the close button
	if ( info.closeButton ) then
		local closeButton = _G[dialog:GetName().."CloseButton"];
		if ( info.closeButtonIsHide ) then
			closeButton:SetNormalTexture("Interface\\Buttons\\UI-Panel-HideButton-Up");
			closeButton:SetPushedTexture("Interface\\Buttons\\UI-Panel-HideButton-Down");
		else
			closeButton:SetNormalTexture("Interface\\Buttons\\UI-Panel-MinimizeButton-Up");
			closeButton:SetPushedTexture("Interface\\Buttons\\UI-Panel-MinimizeButton-Down");
		end
		closeButton:Show();
	else
		_G[dialog:GetName().."CloseButton"]:Hide();
	end

	-- Set the editbox of the dialog
	local editBox = _G[dialog:GetName().."EditBox"];
	if ( info.hasEditBox ) then
		editBox:Show();

		if ( info.maxLetters ) then
			editBox:SetMaxLetters(info.maxLetters);
			editBox:SetCountInvisibleLetters(info.countInvisibleLetters);
		end
		if ( info.maxBytes ) then
			editBox:SetMaxBytes(info.maxBytes);
		end
		editBox:SetText("");
		if ( info.editBoxWidth ) then
			editBox:SCWidth(info.editBoxWidth);
		else
			editBox:SCWidth(130);
		end
	else
		editBox:Hide();
	end

	-- Show or hide money frame
	if ( info.hasMoneyFrame ) then
		_G[dialog:GetName().."MoneyFrame"]:Show();
		_G[dialog:GetName().."MoneyInputFrame"]:Hide();
	elseif ( info.hasMoneyInputFrame ) then
		local moneyInputFrame = _G[dialog:GetName().."MoneyInputFrame"];
		moneyInputFrame:Show();
		_G[dialog:GetName().."MoneyFrame"]:Hide();
		-- Set OnEnterPress for money input frames
		if ( info.EditBoxOnEnterPressed ) then
			moneyInputFrame.gold:SetScript("OnEnterPressed", SC.StaticPopup_EditBoxOnEnterPressed);
			moneyInputFrame.silver:SetScript("OnEnterPressed", SC.StaticPopup_EditBoxOnEnterPressed);
			moneyInputFrame.copper:SetScript("OnEnterPressed", SC.StaticPopup_EditBoxOnEnterPressed);
		else
			moneyInputFrame.gold:SetScript("OnEnterPressed", nil);
			moneyInputFrame.silver:SetScript("OnEnterPressed", nil);
			moneyInputFrame.copper:SetScript("OnEnterPressed", nil);
		end
	else
		_G[dialog:GetName().."MoneyFrame"]:Hide();
		_G[dialog:GetName().."MoneyInputFrame"]:Hide();
	end

	-- Show or hide item button
	if ( info.hasItemFrame ) then
		_G[dialog:GetName().."ItemFrame"]:Show();
		if ( data and type(data) == "table" ) then
			_G[dialog:GetName().."ItemFrame"].link = data.link
			_G[dialog:GetName().."ItemFrameIconTexture"]:SetTexture(data.texture);
			local nameText = _G[dialog:GetName().."ItemFrameText"];
			nameText:SetTextColor(unpack(data.color or {1, 1, 1, 1}));
			nameText:SetText(data.name);
			if ( data.count and data.count > 1 ) then
				_G[dialog:GetName().."ItemFrameCount"]:SetText(data.count);
				_G[dialog:GetName().."ItemFrameCount"]:Show();
			else
				_G[dialog:GetName().."ItemFrameCount"]:Hide();
			end
		end
	else
		_G[dialog:GetName().."ItemFrame"]:Hide();
	end

	-- Set the miscellaneous variables for the dialog
	dialog.which = which;
	dialog.timeleft = info.timeout;
	dialog.hideOnEscape = info.hideOnEscape;
	dialog.exclusive = info.exclusive;
	dialog.enterClicksFirstButton = info.enterClicksFirstButton;
	-- Clear out data
	dialog.data = data;

	-- Set the buttons of the dialog
	local button1 = _G[dialog:GetName().."Button1"];
	local button2 = _G[dialog:GetName().."Button2"];
	local button3 = _G[dialog:GetName().."Button3"];

	do	--If there is any recursion in this block, we may get errors (tempButtonLocs is static). If you have to recurse, we'll have to create a new table each time.
	assert(#tempButtonLocs == 0);	--If this fails, we're recursing. (See the table.wipe at the end of the block)

	tinsert(tempButtonLocs, button1);
	tinsert(tempButtonLocs, button2);
	tinsert(tempButtonLocs, button3);

	for i=#tempButtonLocs, 1, -1 do
		--Do this stuff before we move it. (This is why we go back-to-front)
		tempButtonLocs[i]:SetText(info["button"..i]);
		tempButtonLocs[i]:Hide();
		tempButtonLocs[i]:ClearAllPoints();
		--Now we possibly remove it.
		if ( not (info["button"..i] and ( not info["DisplayButton"..i] or info["DisplayButton"..i](dialog))) ) then
			tremove(tempButtonLocs, i);
		end
	end

	local numButtons = #tempButtonLocs;
	--Save off the number of buttons.
	dialog.numButtons = numButtons;

	if ( numButtons == 3 ) then
		tempButtonLocs[1]:SCPoint("BOTTOMRIGHT", dialog, "BOTTOM", -72, 16);
	elseif ( numButtons == 2 ) then
		tempButtonLocs[1]:SCPoint("BOTTOMRIGHT", dialog, "BOTTOM", -6, 16);
	elseif ( numButtons == 1 ) then
		tempButtonLocs[1]:SCPoint("BOTTOM", dialog, "BOTTOM", 0, 16);
	end

	for i=1, numButtons do
		if ( i > 1 ) then
			tempButtonLocs[i]:SCPoint("LEFT", tempButtonLocs[i-1], "RIGHT", 13, 0);
		end

		local width = tempButtonLocs[i]:GetTextWidth();
		if ( width > 110 ) then
			tempButtonLocs[i]:SCWidth(width + 20);
		else
			tempButtonLocs[i]:SCWidth(120);
		end
		tempButtonLocs[i]:Enable();
		tempButtonLocs[i]:Show();
	end

	wipe(tempButtonLocs);
	end

	-- Show or hide the alert icon
	local alertIcon = _G[dialog:GetName().."AlertIcon"];
	if ( info.showAlert ) then
		alertIcon:SetTexture(STATICPOPUP_TEXTURE_ALERT);
		if ( button3:IsShown() )then
			alertIcon:SCPoint("LEFT", 24, 10);
		else
			alertIcon:SCPoint("LEFT", 24, 0);
		end
		alertIcon:Show();
	elseif ( info.showAlertGear ) then
		alertIcon:SetTexture(STATICPOPUP_TEXTURE_ALERTGEAR);
		if ( button3:IsShown() )then
			alertIcon:SCPoint("LEFT", 24, 0);
		else
			alertIcon:SCPoint("LEFT", 24, 0);
		end
		alertIcon:Show();
	else
		alertIcon:SetTexture();
		alertIcon:Hide();
	end

	if ( info.StartDelay ) then
		dialog.startDelay = info.StartDelay();
		button1:Disable();
	else
		dialog.startDelay = nil;
		button1:Enable();
	end

	editBox.autoCompleteParams = info.autoCompleteParams;
	editBox.autoCompleteRegex = info.autoCompleteRegex;
	editBox.autoCompleteFormatRegex = info.autoCompleteFormatRegex;

	editBox.addHighlightedText = true;

	-- Finally size and show the dialog
	SliceCommander:StaticPopup_SetUpPosition(dialog);
	dialog:Show();

	SliceCommander:StaticPopup_Resize(dialog, which);

	if ( info.sound ) then
		PlaySound(info.sound);
	end

	return dialog;
end

function SliceCommander:StaticPopup_Hide(which, data)
	for index = 1, MAX_STATIC_POPUPS, 1 do
		local dialog = _G["SliceCommander_StaticPopup"..index];
		if ( (dialog.which == which) and (not data or (data == dialog.data)) ) then
			dialog:Hide();
		end
	end
end

function SliceCommander:Contruct_StaticPopups()
	SC.StaticPopupFrames = {}

	for index = 1, MAX_STATIC_POPUPS do
		SC.StaticPopupFrames[index] = CreateFrame('Frame', 'SliceCommander_StaticPopup'..index, UIParent, 'StaticPopupTemplate')
		SC.StaticPopupFrames[index]:SetID(index)

		--Fix Scripts
		SC.StaticPopupFrames[index]:SetScript('OnShow', SC.StaticPopup_OnShow)
		SC.StaticPopupFrames[index]:SetScript('OnHide', SC.StaticPopup_OnHide)
		SC.StaticPopupFrames[index]:SetScript('OnUpdate', SC.StaticPopup_OnUpdate)
		SC.StaticPopupFrames[index]:SetScript('OnEvent', SC.StaticPopup_OnEvent)

		for i = 1, 3 do
			_G['SliceCommander_StaticPopup'..index..'Button'..i]:SetScript('OnClick', function(self)
				SliceCommander.StaticPopup_OnClick(self:GetParent(), self:GetID())
			end)
		end

		_G['SliceCommander_StaticPopup'..index..'EditBox']:SetScript('OnEnterPressed', SC.StaticPopup_EditBoxOnEnterPressed)
		_G['SliceCommander_StaticPopup'..index..'EditBox']:SetScript('OnEscapePressed', SC.StaticPopup_EditBoxOnEscapePressed)
		_G['SliceCommander_StaticPopup'..index..'EditBox']:SetScript('OnTextChanged', SC.StaticPopup_EditBoxOnTextChanged)

	end

	SliceCommander:SecureHook('StaticPopup_SetUpPosition')
	SliceCommander:SecureHook('StaticPopup_CollapseTable')
end